pub struct SampleGeneratorConfig {
pub items_per_sample: (u32, u32),
pub correct_ratio: f64,
pub misstatement_ratio: f64,
pub exception_ratio: f64,
pub generate_for_non_sampling: bool,
}Expand description
Configuration for the sample generator (ISA 530).
Fields
items_per_sample: (u32, u32)Number of items to include in each sample (min, max)
correct_ratio: f64Fraction of items that are correct (no misstatement)
misstatement_ratio: f64Fraction of items that have a misstatement
exception_ratio: f64Fraction of items that have a deviation / exception
generate_for_non_sampling: boolOnly generate samples for workpapers with statistical sampling methods;
when false, any workpaper with population_size > 0 receives a sample.