DriftEventGenerator

Struct DriftEventGenerator 

pub struct DriftEventGenerator { /* private fields */ }
Generates LabeledDriftEvent instances from organizational events, process evolution events, and standalone random drifts.

Implementations

Source

impl DriftEventGenerator

pub fn new(seed: u64) -> Self

Create a new generator with the given seed and default config.

pub fn with_config(seed: u64, config: DriftEventGeneratorConfig) -> Self

Create a new generator with the given seed and custom config.

pub fn generate_all( &mut self, start_date: NaiveDate, end_date: NaiveDate, org_events: &[OrganizationalEvent], proc_events: &[ProcessEvolutionEvent], ) -> Vec<LabeledDriftEvent>

Generate all drift events: from org events, process events, and standalone.

Results are returned sorted by start_date.

pub fn generate_from_org_events( &mut self, org_events: &[OrganizationalEvent], ) -> Vec<LabeledDriftEvent>

Generate drift events derived from organizational events.

For each org event, with probability config.org_event_drift_prob, creates an Organizational drift label.

pub fn generate_from_process_events( &mut self, proc_events: &[ProcessEvolutionEvent], ) -> Vec<LabeledDriftEvent>

Generate drift events derived from process evolution events.

For each process event, with probability config.process_event_drift_prob, creates a Process drift label.

pub fn generate_standalone_drifts( &mut self, start_date: NaiveDate, end_date: NaiveDate, ) -> Vec<LabeledDriftEvent>

Generate standalone drifts (statistical, temporal, market, behavioral) randomly distributed across the date range.