pub struct DriftEventGeneratorConfig {
pub standalone_drifts_per_year: f64,
pub org_event_drift_prob: f64,
pub process_event_drift_prob: f64,
}Expand description
Configuration for the drift event generator.
Fields
standalone_drifts_per_year: f64Average standalone drifts per year (statistical, temporal, market, behavioral).
org_event_drift_prob: f64Probability of generating a drift from an org event.
process_event_drift_prob: f64Probability of generating a drift from a process event.