pub struct GeneratedFxRates {
pub daily_rates: FxRateTable,
pub period_rates: Vec<FxRate>,
pub start_date: NaiveDate,
pub end_date: NaiveDate,
}Expand description
Container for all generated FX rates.
Fields
daily_rates: FxRateTableDaily spot rates.
period_rates: Vec<FxRate>Period closing and average rates.
start_date: NaiveDateStart date of generation.
end_date: NaiveDateEnd date of generation.
Implementations
Sourceimpl GeneratedFxRates
impl GeneratedFxRates
Sourcepub fn combined_rate_table(&self) -> FxRateTable
pub fn combined_rate_table(&self) -> FxRateTable
Combines all rates into a single rate table.
Sourcepub fn closing_rates_for_date(&self, date: NaiveDate) -> Vec<&FxRate>
pub fn closing_rates_for_date(&self, date: NaiveDate) -> Vec<&FxRate>
Gets closing rates for a specific period end date.
Sourcepub fn average_rates_for_date(&self, date: NaiveDate) -> Vec<&FxRate>
pub fn average_rates_for_date(&self, date: NaiveDate) -> Vec<&FxRate>
Gets average rates for a specific period end date.