pub struct TranslatedTrialBalance {Show 16 fields
pub company_code: String,
pub company_name: String,
pub local_currency: String,
pub group_currency: String,
pub period_end_date: NaiveDate,
pub fiscal_year: i32,
pub fiscal_period: u8,
pub lines: Vec<TranslatedTrialBalanceLine>,
pub closing_rate: Decimal,
pub average_rate: Decimal,
pub total_local_debit: Decimal,
pub total_local_credit: Decimal,
pub total_group_debit: Decimal,
pub total_group_credit: Decimal,
pub cta_amount: Decimal,
pub translation_method: TranslationMethod,
}Expand description
Translated trial balance in group currency.
Fields
company_code: StringCompany code.
company_name: StringCompany name.
local_currency: StringLocal (functional) currency.
group_currency: StringGroup (reporting) currency.
period_end_date: NaiveDatePeriod end date.
fiscal_year: i32Fiscal year.
fiscal_period: u8Fiscal period.
lines: Vec<TranslatedTrialBalanceLine>Translated line items.
closing_rate: DecimalClosing rate used.
average_rate: DecimalAverage rate used.
total_local_debit: DecimalTotal local currency debits.
total_local_credit: DecimalTotal local currency credits.
total_group_debit: DecimalTotal group currency debits.
total_group_credit: DecimalTotal group currency credits.
cta_amount: DecimalCurrency Translation Adjustment amount.
translation_method: TranslationMethodTranslation method used.
Implementations
Sourceimpl TranslatedTrialBalance
impl TranslatedTrialBalance
Sourcepub fn is_local_balanced(&self) -> bool
pub fn is_local_balanced(&self) -> bool
Returns true if the local currency trial balance is balanced.
Sourcepub fn is_group_balanced(&self) -> bool
pub fn is_group_balanced(&self) -> bool
Returns true if the group currency trial balance is balanced (including CTA).
Sourcepub fn local_net_assets(&self) -> Decimal
pub fn local_net_assets(&self) -> Decimal
Gets the net assets in local currency.
Sourcepub fn group_net_assets(&self) -> Decimal
pub fn group_net_assets(&self) -> Decimal
Gets the net assets in group currency.