pub struct CashFlow {
pub date: NaiveDate,
pub account_id: String,
pub amount: Decimal,
pub direction: CashFlowDirection,
}Expand description
An individual cash flow event to be aggregated into positions.
This is a simplified representation that the cash position generator uses to aggregate from various sources (AP payments, AR receipts, payroll, tax).
Fields
date: NaiveDateDate the cash flow occurs
account_id: StringBank account the flow affects
amount: DecimalAbsolute amount of the flow
direction: CashFlowDirectionWhether this is an inflow or outflow