GoingConcernInput

Struct GoingConcernInput 

pub struct GoingConcernInput {
    pub entity_code: String,
    pub net_income: Decimal,
    pub working_capital: Decimal,
    pub operating_cash_flow: Decimal,
    pub total_debt: Decimal,
    pub assessment_date: NaiveDate,
}
Financial metrics derived from actual generated data, used to derive going concern indicators from real financials rather than random draws.

All amounts are in the entity’s reporting currency.

Fields

entity_code: String

Entity code being assessed.

net_income: Decimal

Net income / (loss) for the period (negative = loss).

working_capital: Decimal

Working capital = current assets − current liabilities (negative = deficiency).

operating_cash_flow: Decimal

Net cash from operating activities (negative = outflow).

total_debt: Decimal

Total financial debt outstanding.

assessment_date: NaiveDate

Date the assessment is finalised.