pub struct SamplingPlanGenerator { /* private fields */ }Expand description
Generator for ISA 530 sampling plans and sampled items.
Implementations
Sourceimpl SamplingPlanGenerator
impl SamplingPlanGenerator
Sourcepub fn with_config(seed: u64, config: SamplingPlanGeneratorConfig) -> Self
pub fn with_config(seed: u64, config: SamplingPlanGeneratorConfig) -> Self
Create a new generator with custom configuration.
Sourcepub fn generate_for_cras(
&mut self,
cras: &[CombinedRiskAssessment],
tolerable_error: Option<Decimal>,
) -> (Vec<SamplingPlan>, Vec<SampledItem>)
pub fn generate_for_cras( &mut self, cras: &[CombinedRiskAssessment], tolerable_error: Option<Decimal>, ) -> (Vec<SamplingPlan>, Vec<SampledItem>)
Generate sampling plans and sampled items for all CRAs at Moderate or higher.
Arguments
cras— All combined risk assessments for one or more entities.tolerable_error— Performance materiality / tolerable error for the entity. WhenNone, a synthetic TE of 5% of the base population value is used.
Returns (plans, sampled_items) — the plans and the flat list of all sampled items.