pub struct RegulationGenerator { /* private fields */ }Expand description
Generator that produces compliance regulation output data from the registry.
Implementations
Sourceimpl RegulationGenerator
impl RegulationGenerator
Sourcepub fn with_registry(registry: StandardRegistry) -> Self
pub fn with_registry(registry: StandardRegistry) -> Self
Creates a generator with a custom registry.
Sourcepub fn registry(&self) -> &StandardRegistry
pub fn registry(&self) -> &StandardRegistry
Returns a reference to the underlying registry.
Sourcepub fn generate_standard_records(
&self,
jurisdictions: &[String],
reference_date: NaiveDate,
) -> Vec<ComplianceStandardRecord>
pub fn generate_standard_records( &self, jurisdictions: &[String], reference_date: NaiveDate, ) -> Vec<ComplianceStandardRecord>
Generates standard records for a set of jurisdictions at a reference date.
Sourcepub fn generate_cross_reference_records(&self) -> Vec<CrossReferenceRecord>
pub fn generate_cross_reference_records(&self) -> Vec<CrossReferenceRecord>
Generates cross-reference records.
Sourcepub fn generate_jurisdiction_records(
&self,
jurisdictions: &[String],
reference_date: NaiveDate,
) -> Vec<JurisdictionRecord>
pub fn generate_jurisdiction_records( &self, jurisdictions: &[String], reference_date: NaiveDate, ) -> Vec<JurisdictionRecord>
Generates jurisdiction profile records.