pub struct CurrencyTranslator { /* private fields */ }Expand description
Currency translator for financial statements.
Implementations
Sourceimpl CurrencyTranslator
impl CurrencyTranslator
Sourcepub fn new_with_framework(
config: CurrencyTranslatorConfig,
framework: &str,
) -> Self
pub fn new_with_framework( config: CurrencyTranslatorConfig, framework: &str, ) -> Self
Creates a new currency translator for a specific accounting framework.
Sourcepub fn new(config: CurrencyTranslatorConfig) -> Self
pub fn new(config: CurrencyTranslatorConfig) -> Self
Creates a new currency translator (defaults to US GAAP).
Sourcepub fn set_historical_equity_rates(&mut self, rates: HashMap<String, Decimal>)
pub fn set_historical_equity_rates(&mut self, rates: HashMap<String, Decimal>)
Sets historical equity rates for specific accounts.
These rates are used when translating equity accounts under the Temporal or MonetaryNonMonetary methods. The rates represent the exchange rate at the time equity transactions originally occurred.
Sourcepub fn translate_trial_balance(
&self,
trial_balance: &TrialBalance,
rate_table: &FxRateTable,
historical_rates: &HashMap<String, Decimal>,
) -> TranslatedTrialBalance
pub fn translate_trial_balance( &self, trial_balance: &TrialBalance, rate_table: &FxRateTable, historical_rates: &HashMap<String, Decimal>, ) -> TranslatedTrialBalance
Translates a trial balance from local to group currency.
Sourcepub fn translate_amount(
&self,
amount: Decimal,
local_currency: &str,
account_code: &str,
account_type: &TranslationAccountType,
rate_table: &FxRateTable,
date: NaiveDate,
) -> TranslatedAmount
pub fn translate_amount( &self, amount: Decimal, local_currency: &str, account_code: &str, account_type: &TranslationAccountType, rate_table: &FxRateTable, date: NaiveDate, ) -> TranslatedAmount
Translates a single amount.
For equity accounts, this method will use historical equity rates set
via set_historical_equity_rates if available, falling back to
Decimal::ONE when no historical rate is found.